#!/bin/sh

#####################################################################
echo
echo "--------------------------------------------------------------"
echo "--- Step 0. Figure out what we are doing"
echo "--------------------------------------------------------------"
echo

if [ $1 ]
then
   SPUTNIK_DIR=$1      # "SPUTNIK_DIR" really is "the Kepler directory"
   echo "0.1 I will install Kepler and Sputnik into $SPUTNIK_DIR."
else
   echo "Please tell me where you want to install Kepler and Sputnik!"
   echo "This should be the first argument to the script"
   echo
   echo
   exit
fi

TEMP_DIR="tmp/"    # change to ~/tmp/ if your system won't let you build in /tmp/
echo "0.2 I will use $TEMP_DIR as the temporary directory. (Change this to "
echo "    something like ~/tmp/ if your system won't let you build in $TEMP_DIR"


WIKI_DATA_DIR="$SPUTNIK_DIR/wiki-data/"
if [ $2 ]
then
   CGI_URL=$2
   echo "0.3 You told me that Sputnik's URL will be $CGI_URL"
else
   CGI_URL="/cgi-bin/sputnik.cgi"
   echo "0.3 Sputnik's URL will be $CGI_URL (the default)."
fi

LOG_FILE="/tmp/log.txt"
echo "0.4 All the details will go to $LOG_FILE."
echo "" > $LOG_FILE

echo "\n    Ok, let's move on to the actual installation.\n"

#####################################################################
echo
echo "--------------------------------------------------------------"
echo "--- Step 1. Download, build, and install Kepler"
echo "--------------------------------------------------------------"
echo
### cd to $TEMP_DIR directory, to avoid polluting the local directory
### with temporary files

OLD_DIR=$PWD
cd $TEMP_DIR

### download and untar Kepler

#ARCHIVE_NAME="kepler-1.1-snapshot-20071106-1842.tar.gz"
#ARCHIVE_NAME="kepler-1.1-snapshot-20071109-1918.tar.gz"
ARCHIVE_NAME="kepler-1.1beta1.tar.gz"
ARCHIVE_NAME="kepler-1.1-snapshot-20071111-1826.tar.gz"
BASE_URL="http://luaforge.net/frs/download.php/2594/"
BASE_URL="http://www.keplerproject.org/"
DIR_NAME="kepler-1.1"

if [ -f $ARCHIVE_NAME ]
then
  echo "1.1 Skipping download - kepler archive already in $TEMP_DIR"
else
  echo "1.1 Downloading Kepler..."
  wget $BASE_URL$ARCHIVE_NAME
fi
if [ -f $DIR_NAME ]
then
  echo "1.2 Skipping untarring - there is already a kepler-1.1 directory"
else
  echo "1.2 Unpacking Kepler..."
  tar xvzf $ARCHIVE_NAME >> $LOG_FILE
fi
cd kepler-1.1


### configure, build and install kepler into $SPUTNIK_DIR
echo "1.3 Configuring and building... (this might take around minute)"
./configure --prefix=$SPUTNIK_DIR --launcher=cgi --without-readline --enable-lua >> $LOG_FILE
make >> $LOG_FILE
make install >> $LOG_FILE

### return to the sputnik-wiki directory
cd $OLD_DIR

#####################################################################
echo
echo "--------------------------------------------------------------"
echo "--- Step 2. Install Sputnik"
echo "--------------------------------------------------------------"
echo

$SPUTNIK_DIR/bin/lua5.1 install.lua $SPUTNIK_DIR/etc/kepler/1.1/kepler_init.lua \
    $SPUTNIK_DIR $WIKI_DATA_DIR $CGI_URL

echo

echo "You should now be almost done.  Copy sputnik.cgi to your cgi-bin"
echo "directory, e.g.:"
echo "    sudo cp sputnik.cgi /usr/lib/cgi-bin/"
echo
echo "After that, access Sputnik at http://localhost$CGI_URL/sputnik.cgi"
echo
echo

### rename cgi to sputnik.cgi
#cp $SPUTNIK_DIR/bin/cgi sputnik.cgi

### copy the lua files to where they need to be
#cp *.lua $SPUTNIK_DIR/share/lua/5.1/
#cp -r sputnik $SPUTNIK_DIR/share/lua/5.1/
#cp examples/*.lua $SPUTNIK_DIR/share/lua/5.1/
#cp dependencies/*.lua $SPUTNIK_DIR/share/lua/5.1
#cp luasvn/*.so $SPUTNIK_DIR/lib/lua/5.1

### copy the data files (if installing from SVN, we need to create them first
# $SPUTNIK_DIR/bin/lua5.1 scripts/make_data_dir.lua wiki-data
#cp -r wiki-data/* $WIKI_DATA_DIR
#chmod -R a+rw $WIKI_DATA_DIR

### make a config file and copy it to Kepler

#$SPUTNIK_DIR/bin/lua5.1 scripts/make_config_file.lua $SPUTNIK_DIR/etc/kepler/1.1/kepler_init.lua \
#    $SPUTNIK_DIR $WIKI_DATA_DIR $CGI_URL    
#cp sputnik_config.lua $SPUTNIK_DIR/share/lua/5.1/sputnik_config.lua

#cp cgilua.config.lua $SPUTNIK_DIR/etc/kepler/1.1/cgilua/config.lua
#cp cgilua_sputnik.lua $SPUTNIK_DIR/

